@@ -3,14 +3,11 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 3.0.1 (2021-11-22)
+   Version: 4.0.0 (2022-04-30)
    Website: http://www.gingerblue.org/
    
 */
 
-#ifndef _GINGERBLUE_FILE_H_
-#define _GINGERBLUE_FILE_H_ 1
-
 #include <libxml/xmlmemory.h>
 #include <libxml/parser.h>
 
@@ -18,4 +15,3 @@ GingerblueData *gb_file_config_load (GingerblueData *head, gchar *filename);
 
 static void gb_file_parse_volume (GingerblueData *data, xmlDocPtr doc, xmlNodePtr cur);
 
-#endif /* _GINGERBLUE_FILE_H_ */
