@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 3.0.1 (2021-11-22)
+   Version: 4.0.0 (2022-04-30)
    Website: http://www.gingerblue.org/
 
  */
@@ -68,9 +68,6 @@ GstTagList *tag_list;
 
 GError *error = NULL;
 
-gchar *htmlfile = NULL;
-gchar *htmlfp = NULL;
-
 static void gb_assistant_entry_changed(GtkEditable * editable,
 				       GtkAssistant * assistant,
 				       GstElement * pipeline)
@@ -113,24 +110,9 @@ static void gb_assistant_button_clicked(GtkButton * button,
 	filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
 			       gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 			       gtk_entry_get_text(GTK_ENTRY(song_entry)), "_[",
-			       g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"),
+			       g_date_time_format_iso8601 (datestamp),
 			       "]",
 			       ".ogg", NULL);
-	htmlfile = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
-			       gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
-			       gtk_entry_get_text(GTK_ENTRY(song_entry)), "_[",
-			       g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"),
-			       "]",
-			       ".html", NULL);
-	htmlfp = fopen(htmlfile, "w");
-	fprintf(htmlfp, "<html>\n  <head>\n    <title>%s - %s</title>\n  </head>\n  <body>\n    <h1>%s</h1>\n", gtk_entry_get_text(GTK_ENTRY(musician_entry)), gtk_entry_get_text(GTK_ENTRY(song_entry)), gtk_entry_get_text(GTK_ENTRY(musician_entry)), gtk_entry_get_text(GTK_ENTRY(song_entry)));
-	fprintf(htmlfp, "<h2><a href='http://wiki.gnome.org/Apps/Gingerblue'>Gingerblue 3.0.1</a></h2>\n");
-	fprintf(htmlfp, "<p><a href='%s'>%s</a> (Ogg Vorbis, 48kHz, Mono)",
-		gtk_entry_get_text(GTK_ENTRY(recording_entry)),
-		g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC),
-			    "/", gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
-			    gtk_entry_get_text(GTK_ENTRY(song_entry)),
-			    ".ogg", NULL));
 	g_object_set(G_OBJECT(sink), "location",
 		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC),
 				 "/", gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
@@ -186,16 +168,9 @@ static void gb_assistant_close(GtkAssistant * assistant, gpointer data)
 	    g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
 			gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 			gtk_entry_get_text(GTK_ENTRY(song_entry)),  "_[",
-			g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"), "]",
+			g_date_time_format_iso8601 (datestamp), "]",
 			".gingerblue", NULL);
-	gchar *htmlfile = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
-			gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
-			gtk_entry_get_text(GTK_ENTRY(song_entry)),  "_[",
-			g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"), "]",
-			".html", NULL);
-
-	htmlfp = fopen(htmlfile, "a+");
-	fprintf(fp, "<p><a href='%s'>%s (%s)</a></p>", filename, gtk_entry_get_text(GTK_ENTRY(musician_entry)), gtk_entry_get_text(GTK_ENTRY(instrument_entry)));
+	fp = fopen(filename, "w");
 	fprintf(fp, "<?xml version='1.0' encoding='UTF-8'?>\n");
 	fprintf(fp, "<gingerblue version='%s'>\n", VERSION);
 	fprintf(fp, "  <musician>%s</musician>\n",
@@ -235,11 +210,6 @@ static void gb_assistant_apply(GtkAssistant * assistant, gpointer data)
 	gst_element_send_event(data, gst_event_new_eos());
 }
 
-static void gb_record_cb (char *path, gpointer data)
-{
-        return;
-}
-
 GtkAssistantPageFunc gb_assistant_cb(GtkAssistant * assistant,
 				     GDateTime * datestamp)
 {
@@ -296,7 +266,7 @@ int main(int argc, char **argv)
 	gchar *filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
 				      gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 				      gtk_entry_get_text(GTK_ENTRY(song_entry)), "_[",
-				      g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"), "]",
+				      g_date_time_format_iso8601 (datestamp), "]",
 				      ".ogg", NULL);
 	gtk_init(&argc, &argv);
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -317,7 +287,7 @@ int main(int argc, char **argv)
 	page[2].widget = gtk_box_new(FALSE, 5);
 	song_label = gtk_label_new(_("Song:"));
 	song_entry = gtk_entry_new();
-	if (g_strcmp0(song_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(song_entry), g_strconcat (_("Song_-_"), g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"), NULL)); else gtk_entry_set_text(GTK_ENTRY(song_entry), gtk_entry_get_text(GTK_ENTRY(song_entry)));
+	if (g_strcmp0(song_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(song_entry), g_strconcat (_("Song_-_"), g_date_time_format_iso8601 (datestamp), NULL)); else gtk_entry_set_text(GTK_ENTRY(song_entry), gtk_entry_get_text(GTK_ENTRY(song_entry)));
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(song_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(song_entry),
@@ -516,7 +486,7 @@ int main(int argc, char **argv)
 	filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
 			       gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 			       gtk_entry_get_text(GTK_ENTRY(song_entry)),"_[",
-			       g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"), "]",
+			       g_date_time_format_iso8601 (datestamp), "]",
 			       ".ogg", NULL);
 	g_object_set(G_OBJECT(sink), "location",
 		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC),
@@ -563,11 +533,6 @@ int main(int argc, char **argv)
 	fprintf(xspf, "</playlist>\n");
 	fclose(xspf);
 
-	htmlfp = fopen(htmlfile, "a+");
-	htmlfp = fprintf(htmlfp, "<p>XSPF: <a href='%s'>%s</a></p>", g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(GTK_ENTRY(label_entry)), ".xspf", NULL), g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(GTK_ENTRY(label_entry)), ".xspf", NULL));
-	fprintf(htmlfp, "  </body>\n</html>\n");
-	fclose(htmlfp);
-
 	gtk_main();
 	return (0);
 }
