@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 3.0.1 (2021-11-22)
+   Version: 4.0.0 (2022-04-30)
    Website: http://www.gingerblue.org/
    
 */
@@ -16,14 +16,12 @@
 #include <stdio.h>
 #include <string.h>
 
-#ifndef _GINGERBLUE_RECORD_H_
-#define _GINGERBLUE_RECORD_H_ 1
-
 static gboolean message_cb (GstBus * bus, GstMessage * message, gpointer user_data);
 static GstPadProbeReturn unlink_cb(GstPad *pad, GstPadProbeInfo *info, gpointer user_data);
 void stopRecording();
 void startRecording();
 int sigintHandler(int unused);
+int gb_record_cb (gchar *path);
 
 int gingerblue_record_begin();
 int gingerblue_record_end();
@@ -31,5 +29,3 @@ int gingerblue_record_end();
 typedef struct _GingerblueRecord {
   gboolean recording_found;
 } GingerblueRecord;
-
-#endif /* _GINGERBLUE_RECORD_H_ */
